@@ -13,6 +13,7 @@ from pymatgen.transformations.standard_transformations import (
 )
 
 from matbench_genmetrics.core import GenMatcher, GenMetrics, MPTSMetrics
+from matbench_genmetrics.utils.featurize import cdvae_cov_struct_fingerprints
 
 # from pytest_cases import fixture, parametrize, parametrize_with_cases
 
@@ -197,6 +198,10 @@ def test_cdvae_coverage():
     print(mptm.recorded_metrics)
 
 
+def test_cdvae_cov_struct_fingerprints():
+    cdvae_cov_struct_fingerprints(dummy_structures, verbose=True)
+
+
 # %% Code Graveyard
 # def flatten_params(
 #     fixtures: List[Callable], expecteds: List[dict]
